@@ -23,9 +23,9 @@ def add_project_metadata(base_dir: str, app_name: str, template: templateUtils.T
         f.write(json.dumps({
             'app_name': app_name,
             'base_dir': app_path,
-            'template': template,
+            'template': template if type(template) == str else template.value,
             'create_time': str(datetime.datetime.now()),
-            'last_update': str(datetime.datetime.now())
+            'last_update': str(datetime.datetime.now()),
         }))
 
 
